"use strict";

var helpers = require("../../helpers/helpers");

exports["Asia/Beirut"] = {

	"guess:by:offset" : helpers.makeTestGuess("Asia/Beirut", { offset: true }),

	"guess:by:abbr" : helpers.makeTestGuess("Asia/Beirut", { abbr: true }),

	"1920" : helpers.makeTestYear("Asia/Beirut", [
		["1920-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["1920-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1920-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1920-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1921" : helpers.makeTestYear("Asia/Beirut", [
		["1921-04-02T21:59:59+00:00", "23:59:59", "EET", -120],
		["1921-04-02T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1921-10-02T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1921-10-02T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1922" : helpers.makeTestYear("Asia/Beirut", [
		["1922-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["1922-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1922-10-07T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1922-10-07T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1923" : helpers.makeTestYear("Asia/Beirut", [
		["1923-04-21T21:59:59+00:00", "23:59:59", "EET", -120],
		["1923-04-21T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1923-09-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1923-09-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1957" : helpers.makeTestYear("Asia/Beirut", [
		["1957-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1957-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1957-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1957-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1958" : helpers.makeTestYear("Asia/Beirut", [
		["1958-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1958-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1958-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1958-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1959" : helpers.makeTestYear("Asia/Beirut", [
		["1959-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1959-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1959-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1959-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1960" : helpers.makeTestYear("Asia/Beirut", [
		["1960-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1960-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1960-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1960-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1961" : helpers.makeTestYear("Asia/Beirut", [
		["1961-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1961-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1961-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1961-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1972" : helpers.makeTestYear("Asia/Beirut", [
		["1972-06-21T21:59:59+00:00", "23:59:59", "EET", -120],
		["1972-06-21T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1972-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1972-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1973" : helpers.makeTestYear("Asia/Beirut", [
		["1973-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1973-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1973-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1973-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1974" : helpers.makeTestYear("Asia/Beirut", [
		["1974-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1974-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1974-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1974-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1975" : helpers.makeTestYear("Asia/Beirut", [
		["1975-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1975-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1975-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1975-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1976" : helpers.makeTestYear("Asia/Beirut", [
		["1976-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1976-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1976-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1976-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1977" : helpers.makeTestYear("Asia/Beirut", [
		["1977-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1977-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1977-09-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1977-09-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1978" : helpers.makeTestYear("Asia/Beirut", [
		["1978-04-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["1978-04-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1978-09-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1978-09-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1984" : helpers.makeTestYear("Asia/Beirut", [
		["1984-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1984-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1984-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1984-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1985" : helpers.makeTestYear("Asia/Beirut", [
		["1985-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1985-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1985-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1985-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1986" : helpers.makeTestYear("Asia/Beirut", [
		["1986-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1986-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1986-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1986-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1987" : helpers.makeTestYear("Asia/Beirut", [
		["1987-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1987-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1987-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1987-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1988" : helpers.makeTestYear("Asia/Beirut", [
		["1988-05-31T21:59:59+00:00", "23:59:59", "EET", -120],
		["1988-05-31T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1988-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1988-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1989" : helpers.makeTestYear("Asia/Beirut", [
		["1989-05-09T21:59:59+00:00", "23:59:59", "EET", -120],
		["1989-05-09T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1989-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1989-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1990" : helpers.makeTestYear("Asia/Beirut", [
		["1990-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1990-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1990-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1990-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1991" : helpers.makeTestYear("Asia/Beirut", [
		["1991-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1991-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1991-10-15T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1991-10-15T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1992" : helpers.makeTestYear("Asia/Beirut", [
		["1992-04-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1992-04-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1992-10-03T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1992-10-03T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1993" : helpers.makeTestYear("Asia/Beirut", [
		["1993-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["1993-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1993-09-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1993-09-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1994" : helpers.makeTestYear("Asia/Beirut", [
		["1994-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["1994-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1994-09-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1994-09-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1995" : helpers.makeTestYear("Asia/Beirut", [
		["1995-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["1995-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1995-09-23T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1995-09-23T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1996" : helpers.makeTestYear("Asia/Beirut", [
		["1996-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["1996-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1996-09-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1996-09-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1997" : helpers.makeTestYear("Asia/Beirut", [
		["1997-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["1997-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1997-09-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1997-09-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1998" : helpers.makeTestYear("Asia/Beirut", [
		["1998-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["1998-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1998-09-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1998-09-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"1999" : helpers.makeTestYear("Asia/Beirut", [
		["1999-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["1999-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["1999-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["1999-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2000" : helpers.makeTestYear("Asia/Beirut", [
		["2000-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2000-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2000-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2000-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2001" : helpers.makeTestYear("Asia/Beirut", [
		["2001-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2001-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2001-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2001-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2002" : helpers.makeTestYear("Asia/Beirut", [
		["2002-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["2002-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2002-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2002-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2003" : helpers.makeTestYear("Asia/Beirut", [
		["2003-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2003-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2003-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2003-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2004" : helpers.makeTestYear("Asia/Beirut", [
		["2004-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["2004-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2004-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2004-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2005" : helpers.makeTestYear("Asia/Beirut", [
		["2005-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["2005-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2005-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2005-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2006" : helpers.makeTestYear("Asia/Beirut", [
		["2006-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2006-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2006-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2006-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2007" : helpers.makeTestYear("Asia/Beirut", [
		["2007-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2007-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2007-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2007-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2008" : helpers.makeTestYear("Asia/Beirut", [
		["2008-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2008-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2008-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2008-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2009" : helpers.makeTestYear("Asia/Beirut", [
		["2009-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["2009-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2009-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2009-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2010" : helpers.makeTestYear("Asia/Beirut", [
		["2010-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["2010-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2010-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2010-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2011" : helpers.makeTestYear("Asia/Beirut", [
		["2011-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["2011-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2011-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2011-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2012" : helpers.makeTestYear("Asia/Beirut", [
		["2012-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2012-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2012-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2012-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2013" : helpers.makeTestYear("Asia/Beirut", [
		["2013-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["2013-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2013-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2013-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2014" : helpers.makeTestYear("Asia/Beirut", [
		["2014-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2014-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2014-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2014-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2015" : helpers.makeTestYear("Asia/Beirut", [
		["2015-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["2015-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2015-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2015-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2016" : helpers.makeTestYear("Asia/Beirut", [
		["2016-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["2016-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2016-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2016-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2017" : helpers.makeTestYear("Asia/Beirut", [
		["2017-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2017-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2017-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2017-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2018" : helpers.makeTestYear("Asia/Beirut", [
		["2018-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2018-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2018-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2018-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2019" : helpers.makeTestYear("Asia/Beirut", [
		["2019-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["2019-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2019-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2019-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2020" : helpers.makeTestYear("Asia/Beirut", [
		["2020-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["2020-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2020-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2020-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2021" : helpers.makeTestYear("Asia/Beirut", [
		["2021-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["2021-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2021-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2021-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2022" : helpers.makeTestYear("Asia/Beirut", [
		["2022-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["2022-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2022-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2022-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2023" : helpers.makeTestYear("Asia/Beirut", [
		["2023-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2023-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2023-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2023-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2024" : helpers.makeTestYear("Asia/Beirut", [
		["2024-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["2024-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2024-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2024-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2025" : helpers.makeTestYear("Asia/Beirut", [
		["2025-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2025-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2025-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2025-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2026" : helpers.makeTestYear("Asia/Beirut", [
		["2026-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["2026-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2026-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2026-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2027" : helpers.makeTestYear("Asia/Beirut", [
		["2027-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["2027-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2027-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2027-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2028" : helpers.makeTestYear("Asia/Beirut", [
		["2028-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2028-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2028-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2028-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2029" : helpers.makeTestYear("Asia/Beirut", [
		["2029-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2029-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2029-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2029-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2030" : helpers.makeTestYear("Asia/Beirut", [
		["2030-03-30T21:59:59+00:00", "23:59:59", "EET", -120],
		["2030-03-30T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2030-10-26T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2030-10-26T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2031" : helpers.makeTestYear("Asia/Beirut", [
		["2031-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2031-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2031-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2031-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2032" : helpers.makeTestYear("Asia/Beirut", [
		["2032-03-27T21:59:59+00:00", "23:59:59", "EET", -120],
		["2032-03-27T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2032-10-30T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2032-10-30T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2033" : helpers.makeTestYear("Asia/Beirut", [
		["2033-03-26T21:59:59+00:00", "23:59:59", "EET", -120],
		["2033-03-26T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2033-10-29T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2033-10-29T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2034" : helpers.makeTestYear("Asia/Beirut", [
		["2034-03-25T21:59:59+00:00", "23:59:59", "EET", -120],
		["2034-03-25T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2034-10-28T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2034-10-28T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2035" : helpers.makeTestYear("Asia/Beirut", [
		["2035-03-24T21:59:59+00:00", "23:59:59", "EET", -120],
		["2035-03-24T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2035-10-27T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2035-10-27T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2036" : helpers.makeTestYear("Asia/Beirut", [
		["2036-03-29T21:59:59+00:00", "23:59:59", "EET", -120],
		["2036-03-29T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2036-10-25T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2036-10-25T21:00:00+00:00", "23:00:00", "EET", -120]
	]),

	"2037" : helpers.makeTestYear("Asia/Beirut", [
		["2037-03-28T21:59:59+00:00", "23:59:59", "EET", -120],
		["2037-03-28T22:00:00+00:00", "01:00:00", "EEST", -180],
		["2037-10-24T20:59:59+00:00", "23:59:59", "EEST", -180],
		["2037-10-24T21:00:00+00:00", "23:00:00", "EET", -120]
	])
};